@@ -8,10 +8,6 @@ const assert = require('assert')
 
 /* global beforeEach, describe, it */
 
-const o777 = parseInt('777', 8)
-const o666 = parseInt('666', 8)
-const o444 = parseInt('444', 8)
-
 describe('copy', () => {
   let TEST_DIR
 
@@ -27,8 +23,8 @@ describe('copy', () => {
     // var userid = require('userid')
 
     // http://man7.org/linux/man-pages/man2/stat.2.html
-    const S_IFREG = parseInt('0100000', 8) // regular file
-    const S_IFDIR = parseInt('0040000', 8) // directory
+    const S_IFREG = 0o100000 // regular file
+    const S_IFDIR = 0o40000 // directory
 
     // these are Mac specific I think (at least staff), should find Linux equivalent
     let gidWheel
@@ -36,13 +32,13 @@ describe('copy', () => {
 
     try {
       gidWheel = process.getgid() // userid.gid('wheel')
-    } catch (err) {
+    } catch {
       gidWheel = process.getgid()
     }
 
     try {
       gidStaff = process.getgid() // userid.gid('staff')
-    } catch (err) {
+    } catch {
       gidStaff = process.getgid()
     }
 
@@ -54,31 +50,31 @@ describe('copy', () => {
 
     const f1 = path.join(srcDir, 'f1.txt')
     fs.writeFileSync(f1, '')
-    fs.chmodSync(f1, o666)
+    fs.chmodSync(f1, 0o666)
     fs.chownSync(f1, process.getuid(), gidWheel)
     const f1stats = fs.lstatSync(f1)
-    assert.strictEqual(f1stats.mode - S_IFREG, o666)
+    assert.strictEqual(f1stats.mode - S_IFREG, 0o666)
 
     const d1 = path.join(srcDir, 'somedir')
     fs.mkdirSync(d1)
-    fs.chmodSync(d1, o777)
+    fs.chmodSync(d1, 0o777)
     fs.chownSync(d1, process.getuid(), gidStaff)
     const d1stats = fs.lstatSync(d1)
-    assert.strictEqual(d1stats.mode - S_IFDIR, o777)
+    assert.strictEqual(d1stats.mode - S_IFDIR, 0o777)
 
     const f2 = path.join(d1, 'f2.bin')
     fs.writeFileSync(f2, '')
-    fs.chmodSync(f2, o777)
+    fs.chmodSync(f2, 0o777)
     fs.chownSync(f2, process.getuid(), gidStaff)
     const f2stats = fs.lstatSync(f2)
-    assert.strictEqual(f2stats.mode - S_IFREG, o777)
+    assert.strictEqual(f2stats.mode - S_IFREG, 0o777)
 
     const d2 = path.join(srcDir, 'crazydir')
     fs.mkdirSync(d2)
-    fs.chmodSync(d2, o444)
+    fs.chmodSync(d2, 0o444)
     fs.chownSync(d2, process.getuid(), gidWheel)
     const d2stats = fs.lstatSync(d2)
-    assert.strictEqual(d2stats.mode - S_IFDIR, o444)
+    assert.strictEqual(d2stats.mode - S_IFDIR, 0o444)
 
     const destDir = path.join(permDir, 'dest')
     fse.copy(srcDir, destDir, err => {
