@@ -91,13 +91,13 @@ describe('fse-ensure-symlink', () => {
         const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
         const dstContent = fs.readFileSync(dstpath, 'utf8')
         const dstDirContents = fs.readdirSync(dstDir)
-        assert.equal(isSymlink, true)
-        assert.equal(srcContent, dstContent)
+        assert.strictEqual(isSymlink, true)
+        assert.strictEqual(srcContent, dstContent)
         assert(dstDirContents.indexOf(dstBasename) >= 0)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -111,13 +111,13 @@ describe('fse-ensure-symlink', () => {
         const dstBasename = path.basename(dstpath)
         const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
         const dstDirContents = fs.readdirSync(dstDir)
-        assert.equal(isSymlink, true)
+        assert.strictEqual(isSymlink, true)
         assert(dstDirContents.indexOf(dstBasename) >= 0)
         assert.throws(() => fs.readFileSync(dstpath, 'utf8'), Error)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -127,14 +127,14 @@ describe('fse-ensure-symlink', () => {
     it(`should return error when creating symlink file using src ${srcpath} and dst ${dstpath}`, done => {
       const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
       const callback = err => {
-        assert.equal(err instanceof Error, true)
+        assert.strictEqual(err instanceof Error, true)
         // ensure that directories aren't created if there's an error
         const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
-        assert.equal(dstdirExistsBefore, dstdirExistsAfter)
+        assert.strictEqual(dstdirExistsBefore, dstdirExistsAfter)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -146,11 +146,11 @@ describe('fse-ensure-symlink', () => {
       const callback = err => {
         if (err) return done(err)
         const destinationContentAfter = fs.readFileSync(dstpath, 'utf8')
-        assert.equal(destinationContentBefore, destinationContentAfter)
+        assert.strictEqual(destinationContentBefore, destinationContentAfter)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -167,13 +167,13 @@ describe('fse-ensure-symlink', () => {
         const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
         const dstContents = fs.readdirSync(dstpath)
         const dstDirContents = fs.readdirSync(dstDir)
-        assert.equal(isSymlink, true)
-        assert.deepEqual(srcContents, dstContents)
+        assert.strictEqual(isSymlink, true)
+        assert.deepStrictEqual(srcContents, dstContents)
         assert(dstDirContents.indexOf(dstBasename) >= 0)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -187,13 +187,13 @@ describe('fse-ensure-symlink', () => {
         const dstBasename = path.basename(dstpath)
         const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
         const dstDirContents = fs.readdirSync(dstDir)
-        assert.equal(isSymlink, true)
+        assert.strictEqual(isSymlink, true)
         assert(dstDirContents.indexOf(dstBasename) >= 0)
         assert.throws(() => fs.readdirSync(dstpath), Error)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -203,14 +203,14 @@ describe('fse-ensure-symlink', () => {
     it(`should return error when creating symlink dir using src ${srcpath} and dst ${dstpath}`, done => {
       const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
       const callback = err => {
-        assert.equal(err instanceof Error, true)
+        assert.strictEqual(err instanceof Error, true)
         // ensure that directories aren't created if there's an error
         const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
-        assert.equal(dstdirExistsBefore, dstdirExistsAfter)
+        assert.strictEqual(dstdirExistsBefore, dstdirExistsAfter)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -222,11 +222,11 @@ describe('fse-ensure-symlink', () => {
       const callback = err => {
         if (err) return done(err)
         const destinationContentAfter = fs.readdirSync(dstpath)
-        assert.deepEqual(destinationContentBefore, destinationContentAfter)
+        assert.deepStrictEqual(destinationContentBefore, destinationContentAfter)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -234,7 +234,7 @@ describe('fse-ensure-symlink', () => {
     const srcpath = args[0]
     const dstpath = args[1]
     it(`should create symlink file using src ${srcpath} and dst ${dstpath}`, () => {
-      fn.apply(null, args)
+      fn(...args)
       const relative = symlinkPathsSync(srcpath, dstpath)
       const srcContent = fs.readFileSync(relative.toCwd, 'utf8')
       const dstDir = path.dirname(dstpath)
@@ -242,8 +242,8 @@ describe('fse-ensure-symlink', () => {
       const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
       const dstContent = fs.readFileSync(dstpath, 'utf8')
       const dstDirContents = fs.readdirSync(dstDir)
-      assert.equal(isSymlink, true)
-      assert.equal(srcContent, dstContent)
+      assert.strictEqual(isSymlink, true)
+      assert.strictEqual(srcContent, dstContent)
       assert(dstDirContents.indexOf(dstBasename) >= 0)
     })
   }
@@ -252,12 +252,12 @@ describe('fse-ensure-symlink', () => {
     const srcpath = args[0]
     const dstpath = args[1]
     it(`should create broken symlink file using src ${srcpath} and dst ${dstpath}`, () => {
-      fn.apply(null, args)
+      fn(...args)
       const dstDir = path.dirname(dstpath)
       const dstBasename = path.basename(dstpath)
       const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
       const dstDirContents = fs.readdirSync(dstDir)
-      assert.equal(isSymlink, true)
+      assert.strictEqual(isSymlink, true)
       assert(dstDirContents.indexOf(dstBasename) >= 0)
       assert.throws(() => fs.readFileSync(dstpath, 'utf8'), Error)
     })
@@ -270,13 +270,13 @@ describe('fse-ensure-symlink', () => {
       const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
       let err = null
       try {
-        fn.apply(null, args)
+        fn(...args)
       } catch (e) {
         err = e
       }
-      assert.equal(err instanceof Error, true)
+      assert.strictEqual(err instanceof Error, true)
       const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
-      assert.equal(dstdirExistsBefore, dstdirExistsAfter)
+      assert.strictEqual(dstdirExistsBefore, dstdirExistsAfter)
     })
   }
 
@@ -285,9 +285,9 @@ describe('fse-ensure-symlink', () => {
     const dstpath = args[1]
     it(`should do nothing using src ${srcpath} and dst ${dstpath}`, () => {
       const destinationContentBefore = fs.readFileSync(dstpath, 'utf8')
-      fn.apply(null, args)
+      fn(...args)
       const destinationContentAfter = fs.readFileSync(dstpath, 'utf8')
-      assert.equal(destinationContentBefore, destinationContentAfter)
+      assert.strictEqual(destinationContentBefore, destinationContentAfter)
     })
   }
 
@@ -295,7 +295,7 @@ describe('fse-ensure-symlink', () => {
     const srcpath = args[0]
     const dstpath = args[1]
     it(`should create symlink dir using src ${srcpath} and dst ${dstpath}`, () => {
-      fn.apply(null, args)
+      fn(...args)
       const relative = symlinkPathsSync(srcpath, dstpath)
       const srcContents = fs.readdirSync(relative.toCwd)
       const dstDir = path.dirname(dstpath)
@@ -303,8 +303,8 @@ describe('fse-ensure-symlink', () => {
       const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
       const dstContents = fs.readdirSync(dstpath)
       const dstDirContents = fs.readdirSync(dstDir)
-      assert.equal(isSymlink, true)
-      assert.deepEqual(srcContents, dstContents)
+      assert.strictEqual(isSymlink, true)
+      assert.deepStrictEqual(srcContents, dstContents)
       assert(dstDirContents.indexOf(dstBasename) >= 0)
     })
   }
@@ -313,12 +313,12 @@ describe('fse-ensure-symlink', () => {
     const srcpath = args[0]
     const dstpath = args[1]
     it(`should create broken symlink dir using src ${srcpath} and dst ${dstpath}`, () => {
-      fn.apply(null, args)
+      fn(...args)
       const dstDir = path.dirname(dstpath)
       const dstBasename = path.basename(dstpath)
       const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
       const dstDirContents = fs.readdirSync(dstDir)
-      assert.equal(isSymlink, true)
+      assert.strictEqual(isSymlink, true)
       assert(dstDirContents.indexOf(dstBasename) >= 0)
       assert.throws(() => fs.readdirSync(dstpath), Error)
     })
@@ -331,13 +331,13 @@ describe('fse-ensure-symlink', () => {
       const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
       let err = null
       try {
-        fn.apply(null, args)
+        fn(...args)
       } catch (e) {
         err = e
       }
-      assert.equal(err instanceof Error, true)
+      assert.strictEqual(err instanceof Error, true)
       const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
-      assert.equal(dstdirExistsBefore, dstdirExistsAfter)
+      assert.strictEqual(dstdirExistsBefore, dstdirExistsAfter)
     })
   }
 
@@ -346,9 +346,9 @@ describe('fse-ensure-symlink', () => {
     const dstpath = args[1]
     it(`should do nothing using src ${srcpath} and dst ${dstpath}`, () => {
       const destinationContentBefore = fs.readdirSync(dstpath)
-      fn.apply(null, args)
+      fn(...args)
       const destinationContentAfter = fs.readdirSync(dstpath)
-      assert.deepEqual(destinationContentBefore, destinationContentAfter)
+      assert.deepStrictEqual(destinationContentBefore, destinationContentAfter)
     })
   }
 
@@ -402,8 +402,8 @@ describe('fse-ensure-symlink', () => {
             const isSymlink = fs.lstatSync(dstpath).isSymbolicLink()
             const dstContent = fs.readFileSync(dstpath, 'utf8')
             const dstDirContents = fs.readdirSync(dstDir)
-            assert.equal(isSymlink, true)
-            assert.equal(srcContent, dstContent)
+            assert.strictEqual(isSymlink, true)
+            assert.strictEqual(srcContent, dstContent)
             assert(dstDirContents.indexOf(dstBasename) >= 0)
           })
       })
