@@ -5,7 +5,6 @@ const os = require('os')
 const fse = require(process.cwd())
 const path = require('path')
 const assert = require('assert')
-const outputJson = require('../output-json')
 
 /* global beforeEach, describe, it */
 
@@ -23,7 +22,7 @@ describe('json', () => {
       assert(!fs.existsSync(file))
 
       const data = { name: 'JP' }
-      outputJson(file, data, err => {
+      fse.outputJson(file, data, err => {
         if (err) return done(err)
 
         assert(fs.existsSync(file))
@@ -34,12 +33,32 @@ describe('json', () => {
       })
     })
 
+    it('should be mutation-proof', async () => {
+      const dir = path.join(TEST_DIR, 'this-dir', 'certanly-does-not', 'exist')
+      const file = path.join(dir, 'file.json')
+      assert(!fs.existsSync(dir), 'directory cannot exist')
+
+      const name = 'JP'
+      const data = { name }
+      const promise = fse.outputJson(file, data)
+      // Mutate data right after call
+      data.name = 'Ryan'
+      // now await for the call to finish
+      await promise
+
+      assert(fs.existsSync(file))
+      const newData = JSON.parse(fs.readFileSync(file, 'utf8'))
+
+      // mutation did not change data
+      assert.strictEqual(newData.name, name)
+    })
+
     it('should support Promises', () => {
       const file = path.join(TEST_DIR, 'this-dir', 'prob-does-not', 'exist', 'file.json')
       assert(!fs.existsSync(file))
 
       const data = { name: 'JP' }
-      return outputJson(file, data)
+      return fse.outputJson(file, data)
     })
 
     describe('> when an option is passed, like JSON replacer', () => {
@@ -50,7 +69,7 @@ describe('json', () => {
         const replacer = (k, v) => v === 'JP' ? 'Jon Paul' : v
         const data = { name: 'JP' }
 
-        outputJson(file, data, { replacer }, err => {
+        fse.outputJson(file, data, { replacer }, err => {
           assert.ifError(err)
           const newData = JSON.parse(fs.readFileSync(file, 'utf8'))
           assert.strictEqual(newData.name, 'Jon Paul')
